//=============================================================================
// CCPGuardian. -- This actor attaches to a PAWN and keeps them from dying
//=============================================================================
class CCPGuardian expands Info;

#exec Texture Import File=textures\TeleRed.pcx Name=CCPTeleRed Group=CCP Mips=Off Flags=2
#exec Texture Import File=textures\TeleBlue.pcx Name=CCPTeleBlue Group=CCP Mips=Off Flags=2
#exec Texture Import File=textures\TeleGreen.pcx Name=CCPTeleGreen Group=CCP Mips=Off Flags=2
#exec Texture Import File=textures\TeleGold.pcx Name=CCPTeleGold Group=CCP Mips=Off Flags=2


var Pawn Who;
var Weapon WhosGun;
var int WhosAmmoCount;

var int StartingGuardTime;
var int StartingMinGuardTime;
var float fGuardTime;
var float fMinGuardTime;
var int ProtectedShooterPenalty;
var int ProtectedVictimPenalty;
var bool ShowTimer;
var bool FlagCarrierCanSpawnKill;
var bool MGTWeaponsDisableGT;
var bool bFirstTime;

var CCPPCRI_HUDInterface myCCPPCRI_HUDInterface;

var bool bActive;


replication
{
	reliable if( RemoteRole==ROLE_AutonomousProxy ) 
		ChangeSkin;
}

function PostBeginPlay()
{
	//log( "CCPP - CCPGuardian.PostBeginPlay" );
	Super.PostBeginPlay();
	Disable('Tick');
	bFirstTime = true;
}	

event Tick(float DeltaTime)
{
local int TestTeam;
local int iOldMinGuardTime;
local int iOldGuardTime;
local int iMinGuardTime;
local int iGuardTime;

	if (Who==None)		// If not attached, exit
		{
	 	return;
		}

	iOldMinGuardTime = int(fMinGuardTime+0.5);
	iOldGuardTime = int(fGuardTime+0.5);
	if ((fMinGuardTime>0) && (Who.PlayerReplicationInfo.HasFlag == None))
		{
		fMinGuardtime -= DeltaTime;

		if (fMinGuardTime<0)
			{
			fGuardTime -= ABS(fMinGuardTime);
			if ( fGuardTime < 0 )
				fGuardTime = 0;
			fMinGuardTime = 0;
			}

		if ( MGTWeaponsDisableGT )
			{
			if ( ( ( ( Who.Weapon != None ) && ( Who.Weapon != WhosGun ) )
				|| ( ( Who.Weapon == None ) && ( WhosGun != None ) ) )
				|| ( ( Who.Weapon != None ) && ( Who.Weapon.AmmoType != None ) && ( Who.Weapon.AmmoType.AmmoAmount < WhosAmmoCount ) ) )
				{
				fGuardTime = 0;
				}
			else
				{
				if ( ( Who.Weapon != None ) && ( Who.Weapon.AmmoType != None ) && ( Who.Weapon.AmmoType.AmmoAmount > WhosAmmoCount ) )
					WhosAmmoCount = Who.Weapon.AmmoType.AmmoAmount;
				}
			}
		else
			{
			if ( Who.Weapon != None )
				{
				WhosGun = Who.Weapon;
				if ( Who.Weapon.AmmoType != None )
					WhosAmmoCount = Who.Weapon.AmmoType.AmmoAmount;
				}
			}
		}
	else
		{
		fMinGuardTime = 0;
		fGuardTime -= DeltaTime;

		if ( ( ( Who.Weapon != None ) && ( Who.Weapon != WhosGun ) ) ||
			 ( ( Who.Weapon != None ) && ( Who.Weapon.AmmoType != None ) && ( Who.Weapon.AmmoType.AmmoAmount < WhosAmmoCount ) ) ||
			 ( Who.PlayerReplicationInfo.HasFlag != None ) ||
			 ( fGuardTime <= 0 ) )
			{
			if ( fGuardTime < 0 )
				fGuardTime = 0;
		
			// Turn off benifits
			
			bActive = false;
			bHidden=true;
			Disable('Tick');
			}
		else
			{
			if ( ( Who.Weapon != None ) && ( Who.Weapon.AmmoType != None ) && ( Who.Weapon.AmmoType.AmmoAmount > WhosAmmoCount ) )
				WhosAmmoCount = Who.Weapon.AmmoType.AmmoAmount;
			}
		}

	if ( myCCPPCRI_HUDInterface != NONE )		// Update the HUD
		{
		//log( "CCPP - CCPGuardian - Sending settings to myCCPPCRI_HUDInterface" );
		if ( ! bActive )
			myCCPPCRI_HUDInterface.bActive = bActive;
		iMinGuardTime = int(fMinGuardTime+0.5);
		if ( iOldMinGuardTime != iMinGuardTime )
			myCCPPCRI_HUDInterface.iMinGuardTime = iMinGuardTime;
		iGuardTime = int(fGuardTime+0.5);
		if ( iOldGuardTime != iGuardTime )
			myCCPPCRI_HUDInterface.iGuardTime = iGuardTime;
		}
	
	SetLocation(Who.Location);
	SetRotation(Who.Rotation);

}

simulated function ChangeSkin(int team )
{
	local Texture T;

	switch (Team)
		{
		case 0 : 	t = texture 'CCProtector3.CCPTeleRed';
				break;
		case 2 : 	t = texture 'CCProtector3.CCPTeleGreen';
				break;
		case 3 : 	t = texture 'CCProtector3.CCPTeleGold';
				break;
		default:	t = texture 'CCProtector3.CCPTeleBlue';
				break;
		}

	Skin = t;
	MultiSkins[0] = t;
	MultiSkins[1] = t;
	MultiSkins[2] = t;
	MultiSkins[3] = t;
	MultiSkins[4] = t;
	
}

function AttachTo(Pawn Target, int iGTime, int iMGTime, int iPSPenalty, int iPVPenalty, bool bST, bool bMGTSDGT, bool bFCCSPK )
{
local int	  iShowTimerCS;
local int	  iMGTWeaponsDisableGT;
local int	  iFlagCarrierCanSpawnKill;

	//log( "CCPP - CCPGuardian.AttachTo" );

	Who = Target;

	bActive = true;
	SetLocation(Who.Location);
	SetRotation(Who.Rotation);
	fGuardTime = float(iGTime);
	fMinGuardTime = float(iMGTime);
	StartingGuardTime = iGTime;
	StartingMinGuardTime = iMGTime;
	ProtectedShooterPenalty = iPSPenalty;
	ProtectedVictimPenalty = iPVPenalty;
	ShowTimer = bST;
	MGTWeaponsDisableGT = bMGTSDGT;
	FlagCarrierCanSpawnKill = bFCCSPK;
	WhosGun = Who.Weapon;	
	if ( WhosGun != None )
		{
		if ( Who.Weapon.AmmoType != None )
			WhosAmmoCount = Who.Weapon.AmmoType.AmmoAmount;
		else
			WhosAmmoCount = 0;
		}
	bHidden=false;

	ChangeSkin(Who.PlayerReplicationInfo.Team );

	if ( bFirstTime ) 
		{
		if ( ( ShowTimer ) && ( ! Who.IsA('Bot') ) )
			{
			//log( "CCPGaurdian - Spawning CCPPCRI_HUDInterface" );
			myCCPPCRI_HUDInterface = Spawn(class 'CCProtector3.CCPPCRI_HUDInterface',Who,,Who.Location);
			if (myCCPPCRI_HUDInterface!=None)
				{
				//log( "CCPGaurdian - Spawned CCPPCRI_HUDInterface" );
				iShowTimerCS = 0;
				iMGTWeaponsDisableGT = 0;
				myCCPPCRI_HUDInterface.StartingMinGuardTime = StartingMinGuardTime;
				myCCPPCRI_HUDInterface.StartingGuardTime = StartingGuardTime;
				myCCPPCRI_HUDInterface.ProtectedShooterPenalty = ProtectedShooterPenalty;
				myCCPPCRI_HUDInterface.ProtectedVictimPenalty = ProtectedVictimPenalty;
				myCCPPCRI_HUDInterface.ShowTimer = ShowTimer;
				myCCPPCRI_HUDInterface.MGTWeaponsDisableGT = MGTWeaponsDisableGT;
				myCCPPCRI_HUDInterface.FlagCarrierCanSpawnKill = FlagCarrierCanSpawnKill;
				if ( ShowTimer )
					iShowTimerCS = 1;
				if ( MGTWeaponsDisableGT )
					iMGTWeaponsDisableGT = 1;
				myCCPPCRI_HUDInterface.CheckSum = StartingMinGuardTime 
								+ StartingGuardTime
								+ ProtectedShooterPenalty 
								+ ProtectedVictimPenalty
								+ iShowTimerCS
								+ iMGTWeaponsDisableGT
								+ iFlagCarrierCanSpawnKill
								+ 323;
				}
			}
		bFirstTime = false;
		}

	if ( myCCPPCRI_HUDInterface != NONE )		// Update the HUD
		{
		myCCPPCRI_HUDInterface.bActive = bActive;
		myCCPPCRI_HUDInterface.iMinGuardTime = int(fMinGuardTime+0.5);
		myCCPPCRI_HUDInterface.iGuardTime = int(fGuardTime+0.5);
		}

	Enable('Tick');
}

auto state Living
{
	function AnimEnd()
		{
		PlayAnim('Teleport');
		}
	
	function BeginState()
		{
		PlayAnim('TelePort');
		}
}

defaultproperties
{
mesh=LodMesh'Botpack.Tele2'
bHidden=False
DrawType=DT_Mesh
}
